<?php
/**
 * Juliet functions and definitions
 *
 * @package juliet
 */
?>
<?php

/*------------------------------
 Customizer
 ------------------------------*/
 
if ( ! class_exists( 'Kirki' ) ) {
    include_once( dirname( __FILE__ ) . '/inc/kirki/kirki.php' );
}
require get_template_directory() . '/customize/theme-defaults.php';
require get_template_directory() . '/customize/kirki-config.php';
require get_template_directory() . '/customize/customizer.php';

function juliet_customize_register( $wp_customize ) {
    $wp_customize->remove_control('header_textcolor');
    $wp_customize->get_section('colors')->title = esc_html__( 'Custom Colors', 'juliet' );
    $wp_customize->get_section('colors')->priority = 75;
}
add_action( 'customize_register', 'juliet_customize_register' );

if(is_admin())  add_action( 'customize_controls_enqueue_scripts', 'juliet_custom_customize_enqueue' );
function juliet_custom_customize_enqueue() {
    wp_enqueue_style( 'juliet-customizer', get_template_directory_uri() . '/customize/style.css' );
}

/*------------------------------
 Setup
 ------------------------------*/

function juliet_setup() {
    global $juliet_defaults;
    load_theme_textdomain( 'juliet', get_template_directory() . '/languages' ); 
    
    register_nav_menus( array(  'header'    => esc_html__( 'Main Menu', 'juliet' ), 
                                'offcanvas' => esc_html__( 'Off Canvas Menu', 'juliet') ) );
    
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'title-tag' );
    add_theme_support( 'custom-logo', array('height' => 80, 'width' => 250,'flex-height' => true,'flex-width'  => true ) );
    add_theme_support( 'custom-background');
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
    
    $args = array(
        'flex-width'    => true,
        'width'         => 1200,
        'flex-height'    => true,
        'height'        => 625,
        'default-image' => $juliet_defaults['juliet_custom_header'],
    );
    add_theme_support( 'custom-header', $args );

	add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size(            700, 600, true );
    add_image_size( 'juliet-slider',    1200, 550, true );
    add_image_size( 'juliet-thumbnail', 700, 600, true );
	add_image_size( 'juliet-index',     700, 600, true );
    add_image_size( 'juliet-featured',  540, 540, true );
	add_image_size( 'juliet-focus',     580, 600, true );
	
    add_post_type_support('page', 'excerpt');
	
	#https://make.wordpress.org/core/2016/11/26/extending-the-custom-css-editor/
    if ( function_exists( 'wp_update_custom_css_post' ) ) {
        $css = juliet_get_option('juliet_advanced_css');
        if ( $css ) {
            $core_css = wp_get_custom_css(); 
            $return = wp_update_custom_css_post( $core_css . $css );
            if ( ! is_wp_error( $return ) ) {
                remove_theme_mod( 'juliet_advanced_css' );
            }
        }
    }
	
	if ( class_exists( 'WooCommerce' ) ) {
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
		add_theme_support( 'woocommerce' );
	}
    
    juliet_kirki_update_3015();
}
add_action( 'after_setup_theme', 'juliet_setup' );

/*------------------------------
 Styles and Scripts
 ------------------------------*/

function juliet_scripts() {
    
    /* Styles */
    
    $juliet_custom_colors = juliet_get_option('juliet_custom_colors');
    $juliet_custom_typography = juliet_get_option('juliet_custom_typography');
    
	$juliet_skin = juliet_get_option('juliet_skin');
	
    if($juliet_custom_typography == 0) {
        //fonts
		wp_enqueue_style('juliet-googlefont-logo-tagline', '//fonts.googleapis.com/css?family=Crimson+Text:400,400i,600,600i,700,700i'); #logo tagline
		if( $juliet_skin == 'Classic') { 
			wp_enqueue_style('juliet-googlefont-body', '//fonts.googleapis.com/css?family=Lato:400,400i,700,700i'); #body
		} else {
			wp_enqueue_style('juliet-googlefont-body', '//fonts.googleapis.com/css?family=Lato:400,400i,700,700i'); #body
			wp_enqueue_style('juliet-googlefont-headings', '//fonts.googleapis.com/css?family=Montserrat:300,300i,400,400i,500,500i,700,700i'); #headings
		}
    } 
    
	wp_register_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
    wp_register_style('font-awesome', get_template_directory_uri().'/assets/css/font-awesome.min.css' );
	wp_register_style('slick-style', get_template_directory_uri().'/assets/css/slick.min.css' );
    wp_register_style('slick-slider-custom', get_template_directory_uri().'/assets/css/slick-custom.css' );
    wp_register_style('smartmenus-bootstrap', get_template_directory_uri() . '/assets/css/jquery.smartmenus.bootstrap.css' );
	
	//default stylesheet
    $juliet_dropdown_smartmenus_enable = juliet_get_option('juliet_dropdown_smartmenus_enable');
    if($juliet_dropdown_smartmenus_enable == 1)
        $deps = array('bootstrap', 'font-awesome', 'slick-style', 'slick-slider-custom') ; //, 'smartmenus-bootstrap');
    else 
        $deps = array('bootstrap', 'font-awesome', 'slick-style', 'slick-slider-custom');
    $this_theme = wp_get_theme(); 
    wp_enqueue_style('juliet-style', get_stylesheet_uri(), $deps, $this_theme->get( 'Version' ) );
	
	if ( class_exists( 'WooCommerce' ) ) {        
        wp_enqueue_style('juliet-woocommerce-style', get_template_directory_uri().'/woocommerce/woocommerce.css', array( 'juliet-style' ) );
    }
    
    // Load html5shiv.js
	wp_enqueue_script( 'juliet-html5', get_template_directory_uri() . '/assets/js/html5shiv.js', '', '3.7.0' );
	wp_script_add_data( 'juliet-html5', 'conditional', 'lt IE 9' );
    // Load respond.min.js
	wp_enqueue_script( 'juliet-respond', get_template_directory_uri() . '/assets/js/respond.min.js', '', '1.3.0' );
	wp_script_add_data( 'juliet-html5', 'conditional', 'lt IE 9' );
    
    /* Scripts */
    
    wp_enqueue_script('bootstrap', get_template_directory_uri().'/assets/js/bootstrap.min.js', array('jquery'), '', true );
    wp_enqueue_script('slick-slider', get_template_directory_uri() . '/assets/js/slick.min.js', array('jquery'), '', true );

    if(juliet_get_option('juliet_enable_fancy_scrollbar') == 1){
        wp_enqueue_script('nice-scroll', get_template_directory_uri() . '/assets/js/nicescroll.min.js', array('jquery'), '', true );
        wp_enqueue_script('juliet-js', get_template_directory_uri() . '/assets/js/juliet.js', array('jquery', 'bootstrap', 'slick-slider', 'nice-scroll'), '', true );
    } else {
        wp_enqueue_script('juliet-js', get_template_directory_uri() . '/assets/js/juliet.js', array('jquery', 'bootstrap', 'slick-slider'), '', true );
    }
    if($juliet_dropdown_smartmenus_enable == 1){
        wp_enqueue_script('smartmenus', get_template_directory_uri() . '/assets/js/jquery.smartmenus.js', array('jquery','bootstrap'), '', true );
        wp_enqueue_script('smartmenus-bootstrap', get_template_directory_uri() . '/assets/js/jquery.smartmenus.bootstrap.js', array('jquery','bootstrap'), '', true );
    }
	
    //comments
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
    
}
add_action( 'wp_enqueue_scripts', 'juliet_scripts' );


function juliet_admin_scripts($hook) {
    wp_enqueue_script('juliet-metabox-js', get_template_directory_uri() . '/meta_boxes/meta_boxes.js', array('jquery'), '', true );
}
add_action( 'admin_enqueue_scripts', 'juliet_admin_scripts' );

/*------------------------------
 Custom CSS
 ------------------------------*/
 
require get_template_directory() . '/custom/custom_css.php';
function juliet_custom_fonts(){
    $juliet_custom_typography = juliet_get_option('juliet_custom_typography');
    if($juliet_custom_typography == 0) return;
    
    $juliet_custom_typography_body_font = juliet_get_option('juliet_custom_typography_body_font');
    $juliet_custom_typography_logo_font = juliet_get_option('juliet_custom_typography_logo_font');
    $juliet_custom_typography_tagline_font = juliet_get_option('juliet_custom_typography_tagline_font');
    $juliet_custom_typography_heading_font = juliet_get_option('juliet_custom_typography_heading_font');
    $juliet_custom_typography_h1_font = juliet_get_option('juliet_custom_typography_h1_font');
    $juliet_custom_typography_h2_font = juliet_get_option('juliet_custom_typography_h2_font');
    $juliet_custom_typography_h3_font = juliet_get_option('juliet_custom_typography_h3_font');
    $juliet_custom_typography_h4_font = juliet_get_option('juliet_custom_typography_h4_font');
    $juliet_custom_typography_h5_font = juliet_get_option('juliet_custom_typography_h5_font');
    $juliet_custom_typography_h6_font = juliet_get_option('juliet_custom_typography_h6_font');
    
    #body
    $arr['font_body_name'] = $juliet_custom_typography_body_font['font-family'];
    $arr['font_body_size'] = $juliet_custom_typography_body_font['font-size'];
    $arr['font_body_transform'] = $juliet_custom_typography_body_font['text-transform'];
    $arr['font_body_variant'] = $juliet_custom_typography_body_font['variant'];
    #logo
    $arr['font_logo_name'] = $juliet_custom_typography_logo_font['font-family'];
    $arr['font_logo_size'] = $juliet_custom_typography_logo_font['font-size'];
    $arr['font_logo_transform'] = $juliet_custom_typography_logo_font['text-transform'];
    $arr['font_logo_variant'] = $juliet_custom_typography_logo_font['variant'];
    #tagline
    $arr['font_tagline_name'] = $juliet_custom_typography_tagline_font['font-family'];
    $arr['font_tagline_size'] = $juliet_custom_typography_tagline_font['font-size'];
    $arr['font_tagline_transform'] = $juliet_custom_typography_tagline_font['text-transform'];
    $arr['font_tagline_variant'] = $juliet_custom_typography_tagline_font['variant'];
    #headings
    $arr['font_heading_name'] = $juliet_custom_typography_heading_font['font-family'];
    $arr['font_heading_transform'] = $juliet_custom_typography_heading_font['text-transform'];
    $arr['font_heading_variant'] = $juliet_custom_typography_heading_font['variant'];
    $arr['font_h1_size'] = $juliet_custom_typography_h1_font['font-size'];
    $arr['font_h2_size'] = $juliet_custom_typography_h2_font['font-size'];
    $arr['font_h3_size'] = $juliet_custom_typography_h3_font['font-size'];
    $arr['font_h4_size'] = $juliet_custom_typography_h4_font['font-size'];
    $arr['font_h5_size'] = $juliet_custom_typography_h5_font['font-size'];
    $arr['font_h6_size'] = $juliet_custom_typography_h6_font['font-size'];
    global $custom_css_template; $custom_css = $custom_css_template['fonts'];
    foreach($arr as $k=>$v) 
        $custom_css = str_replace("~$k~", $v, $custom_css);
    echo "<style>$custom_css</style>";
}
add_action( 'wp_head', 'juliet_custom_fonts', 96);

function juliet_custom_colors(){
    $juliet_custom_colors = juliet_get_option('juliet_custom_colors');
    if($juliet_custom_colors == 0) return;
    
    $juliet_custom_colors_body = juliet_get_option('juliet_custom_colors_body');
    $juliet_custom_colors_accent = juliet_get_option('juliet_custom_colors_accent');
    $juliet_custom_colors_accent_lighter = juliet_get_option('juliet_custom_colors_accent_lighter');
    
    $arr['color_body'] = $juliet_custom_colors_body;
    $arr['color_accent'] = $juliet_custom_colors_accent;
    $arr['color_accent_lighter'] = $juliet_custom_colors_accent_lighter;
    $arr['color_accent_lighter_rgb'] = hex2rgb($juliet_custom_colors_accent_lighter);
    global $custom_css_template; $custom_css = $custom_css_template['colors'];
    foreach($arr as $k=>$v) 
        $custom_css = str_replace("~$k~", $v, $custom_css);
    echo "<style>$custom_css</style>";
}
add_action( 'wp_head', 'juliet_custom_colors', 97);

if ( ! function_exists( 'juliet_custom_css_banner_overlay' ) ) :
function juliet_custom_css_banner_overlay(){ 
	global $juliet_defaults;
    $juliet_frontpage_banner_overlay_color = juliet_get_option('juliet_frontpage_banner_overlay_color');
	$juliet_frontpage_banner_overlay_show = juliet_get_option('juliet_frontpage_banner_overlay_show');
    if($juliet_frontpage_banner_overlay_show == 0){
		echo "<style>";
		echo ".frontpage-banner:before, .frontpage-slider .item:before, .frontpage-large-post .entry-thumb:before{content:none;}";
		echo "</style>";
	} else if($juliet_frontpage_banner_overlay_color != $juliet_defaults['juliet_frontpage_banner_overlay_color']) {
		echo "<style>";
		echo ".frontpage-banner:before, .frontpage-slider .item:before, .frontpage-large-post .entry-thumb:before{background-color:".esc_attr($juliet_frontpage_banner_overlay_color).";}"; 
		echo "</style>";
	}
} 
endif;
add_action('wp_head','juliet_custom_css_banner_overlay', 98);

if ( ! function_exists( 'juliet_custom_css' ) ) :
function juliet_custom_css() {
    $juliet_advanced_css = juliet_get_option('juliet_advanced_css');
    if($juliet_advanced_css != '') {    
        echo '<!-- Custom CSS -->';
        $output="<style>" . wp_strip_all_tags($juliet_advanced_css) . "</style>";
        echo $output;
        echo '<!-- /Custom CSS -->';
    }
}
endif;
add_action('wp_head','juliet_custom_css', 99);

function juliet_custom_js() {
    $juliet_advanced_analytics = juliet_get_option('juliet_advanced_analytics'); 
    if($juliet_advanced_analytics != '') {
        echo '<!-- Google Analytics -->';
        echo wp_unslash ( $juliet_advanced_analytics ) ;
        echo '<!-- /Google Analytics -->';
    }
}
add_action('wp_head','juliet_custom_js', 100);


/*------------------------------
 Widgets
 ------------------------------*/
require_once get_template_directory() . '/widgets/class.aboutme.widget.php';
require_once get_template_directory() . '/widgets/widgets.php';

/*------------------------------
 Meta Boxes
 ------------------------------*/
require_once get_template_directory() . '/meta_boxes/meta_boxes.php';

/*------------------------------
 Content Width 
 ------------------------------*/
if ( ! isset( $content_width ) ) {
    $content_width = 1200;
}

/*------------------------------
 Theme Updates
 ------------------------------*/

$theme = get_template();
require_once 'theme-updates/theme-update-checker.php';
$checker = new ThemeUpdateChecker( $theme, 'https://s3.amazonaws.com/lyrathemes.com/themes/versions/juliet-pro.json');

#Disable requests to wp.org repository for this theme
# http://wptheming.com/2014/06/disable-theme-update-checks/
function juliet_disable_wporg_request( $r, $url ) {
	if ( 0 !== strpos( $url, 'https://api.wordpress.org/themes/update-check/1.1/' ) ) { return $r; }
    $themes = json_decode( $r['body']['themes'] );
    $parent = get_option( 'template' );
    $child = get_option( 'stylesheet' );
    unset( $themes->themes->$parent );
    unset( $themes->themes->$child );
    $r['body']['themes'] = json_encode( $themes );
    return $r;
}
add_filter( 'http_request_args', 'juliet_disable_wporg_request', 5, 2 );

/*------------------------------
 wp_bootstrap_navwalker
 ------------------------------*/
require_once get_template_directory() . '/inc/wp_bootstrap_navwalker.php';

/*------------------------------
 TGM_Plugin_Activation
 ------------------------------*/

require_once get_template_directory() . '/inc/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'juliet_register_required_plugins' );
function juliet_register_required_plugins() {
	$plugins = array(
        array(
            'name'      => esc_html__('One Click Demo Import', 'juliet'),
            'slug'      => 'one-click-demo-import',
            'required'  => false,
        ),
        array(
			'name'      => esc_html__('Recent Posts Widget With Thumbnails', 'juliet'),
			'slug'      => 'recent-posts-widget-with-thumbnails',
			'required'  => false,
		),
        array(
            'name'      => esc_html__('WP Instagram Widget', 'juliet'),
            'slug'      => 'wp-instagram-widget',
            'required'  => false
        )
	);
	$config = array(
		'id'           => 'juliet',                // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);
	tgmpa( $plugins, $config );
}

/*------------------------------
 One Click Demo Import
 ------------------------------*/

if ( ! function_exists( 'juliet_one_click_demo_import' ) ) :
function juliet_one_click_demo_import() {
    return array(
        array(
            'import_file_name'             => __('Juliet Demo Import', 'juliet'),
            'categories'                   => array( 'Main' ),
            'local_import_file'            => trailingslashit( get_template_directory() ) . 'one-click-demo-import/juliet-pro-demo-content.xml',
            'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'one-click-demo-import/juliet-pro-widgets.wie',
            'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'one-click-demo-import/juliet-pro-options.dat',
            //'import_preview_image_url'     => 'http://www.your_domain.com/ocdi/preview_import_image1.jpg',
            'import_notice'                => __( 'IMPORTANT: Do NOT import demo content if you have existing content / blog posts. The demo import will add new DUMMY posts to your blog. This is only suitable for a new, fresh WordPress installation. Make sure all the recommended plugins are installed before importing the demo. After the import, please set up the slider (Posts Slider or Custom Slider) under Appearance > Customize > Front Page > Banner/Slider. You will also need to assign the Main menu to "Main Menu" location.', 'juliet' ),
            ),
    );
}
endif;
add_filter( 'pt-ocdi/import_files', 'juliet_one_click_demo_import' );

/*------------------------------
 Jetpack
 ------------------------------*/
 
#https://jetpack.com/2013/06/10/moving-sharing-icons/
function jptweak_remove_share() {
    $juliet_blog_feed_share_show = juliet_get_option('juliet_blog_feed_share_show');
    $juliet_posts_share_top_show = juliet_get_option('juliet_posts_share_top_show');
    $juliet_posts_share_bottom_show = juliet_get_option('juliet_posts_share_bottom_show');
    if($juliet_blog_feed_share_show == 1 || $juliet_posts_share_top_show == 1 || $juliet_posts_share_bottom_show == 1) {
        remove_filter( 'the_content', 'sharing_display',19 );
        remove_filter( 'the_excerpt', 'sharing_display',19 );
        if ( class_exists( 'Jetpack_Likes' ) ) {
            remove_filter( 'the_content', array( Jetpack_Likes::init(), 'post_likes' ), 30, 1 );
        }
    }
} 
add_action( 'init', 'jptweak_remove_share');
add_action( 'loop_start', 'jptweak_remove_share' );

/*------------------------------
 Filters
 ------------------------------*/

//https://gist.github.com/hatsumatsu/e5df3b0bf9ac3389c0b0
function juliet_embed_oembed_html( $html, $url, $attributes, $id ) {
    $class = '';
    if( strpos( $url, 'youtu' ) || strpos( $url, 'vimeo' ) ) {
        $class .= ' iframe-video';
    }
    return '<div class="' . esc_attr( $class ) . '">' . $html . '</div>';
}
add_filter( 'embed_oembed_html', 'juliet_embed_oembed_html', 10, 4 );

#disable comments on media attachments
function juliet_filter_media_comment_status( $open, $post_id ) {
	$post = get_post( $post_id );
	if( $post->post_type == 'attachment' ) {
		return false;
	}
	return $open;
}
add_filter( 'comments_open', 'juliet_filter_media_comment_status', 10 , 2 );

#move comment field to the bottom of the comments form
function juliet_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'juliet_move_comment_field_to_bottom' );

#excerpt length
function juliet_excerpt_length( $length ) {
	return 45;
}
add_filter( 'excerpt_length', 'juliet_excerpt_length', 999 );

#get_the_archive_title
function juliet_archive_title( $title ) {
    if( is_home() && get_option('page_for_posts') ) {
        $title = get_page( get_option('page_for_posts') )->post_title;
    }
    else if( is_home() ) {
        $title = juliet_get_option('juliet_blog_feed_label');
        $title = esc_html($title);
    }  
    return $title;
}
add_filter( 'get_the_archive_title', 'juliet_archive_title' );

//https://productforums.google.com/forum/#!topic/webmasters/WUszeNYGNdg
# Remove the "hentry" class from pages and archives (prevents structured data errors)
function remove_hentry( $classes ) {
    if (is_page() || is_archive()){$classes = array_diff( $classes, array('hentry'));}return $classes;
}
add_filter( 'post_class','remove_hentry' );

/*------------------------------------
 Scrollbar, Sticky Nav, Related Posts
 ------------------------------------*/

#nicescroll
function juliet_nice_scroll(){
    if(juliet_get_option('juliet_enable_fancy_scrollbar') != 1) return;
    global $juliet_defaults;
    $juliet_custom_colors = juliet_get_option('juliet_custom_colors');
    if($juliet_custom_colors == 0) $color = $juliet_defaults['juliet_custom_colors_scrollbar'];
    else $color = juliet_get_option('juliet_custom_colors_scrollbar');
    $script = 'jQuery("html").niceScroll({ cursorcolor:"' . esc_attr($color) . '",
                                cursorborder:"' . esc_attr($color) . '",
                                cursoropacitymin:0.2,
                                cursorwidth:10,
                                zindex:10,
                                scrollspeed:60,
                                mousescrollstep:40});';
    wp_add_inline_script( 'juliet-js', $script );
}
add_action( 'wp_enqueue_scripts', 'juliet_nice_scroll', 998 );


#sticky nav
function juliet_sticky_nav(){
	if(juliet_get_option('juliet_enable_sticky_nav')!=1) return;
    $script = 'jQuery(document).ready(function($){
        eventOnScroll();
        $(window).scroll(function(){eventOnScroll();});
    });';
     wp_add_inline_script( 'juliet-js', $script );
}
add_action('wp_enqueue_scripts', 'juliet_sticky_nav', 999);


if ( ! function_exists( 'juliet_get_related_posts' ) ) :
function juliet_get_related_posts($post_id, $n){
    $temp = array();
    $tag_ids = wp_get_post_tags( $post_id, array( 'fields' => 'ids' ) );
    if($tag_ids) { 
        $the_query = new WP_Query( array( 
            'tag__in' => $tag_ids, 
            'ignore_sticky_posts'=>true,
            'posts_per_page' => $n, 
            'post__not_in' => array($post_id), 
            'orderby'=>'comment_count modified', 
            'order'=>'DESC' ) );
        if ( $the_query->have_posts() ) {
            while ( $the_query->have_posts() ) {
                $the_query->the_post();
                $temp[] = get_the_ID();
            }
        }
        wp_reset_postdata();
        if(count($temp)==$n)    return $temp;
    }
    return array();
}
endif;

/*------------------------------
 Example / Default
 ------------------------------*/
if ( ! function_exists( 'juliet_get_sample' ) ) :
function juliet_get_sample($what){
    global $juliet_defaults;
    switch($what){
        case 'juliet-thumbnail':    $images = $juliet_defaults['juliet_thumbnail_sample']; $rand_key = array_rand($images, 1); return ($images[$rand_key]);
        case 'juliet-full':         $images = $juliet_defaults['juliet_full_sample']; $rand_key = array_rand($images, 1); return ($images[$rand_key]);
        case 'juliet-featured':     $images = $juliet_defaults['juliet_featured_sample']; $rand_key = array_rand($images, 1); return ($images[$rand_key]);  
		case 'juliet-slide':        $images = $juliet_defaults['juliet_slide_sample']; $rand_key = array_rand($images, 1); return ($images[$rand_key]);
		case 'juliet-focus':        $images = $juliet_defaults['juliet_focus_sample']; $rand_key = array_rand($images, 1); return ($images[$rand_key]);
    }
}
endif;

#default nav top level pages
function juliet_default_nav(){
	echo '<div class="navbar-collapse collapse">';
    echo '<ul class="nav navbar-nav">';
    $pages = get_pages();  
    $n = count($pages); 
    $i=0;
    foreach ( $pages as $page ) {
        $menu_name = $page->post_title;
        $menu_link = get_page_link( $page->ID );
        if(get_the_ID() == $page->ID) $current_class = "current_page_item";
        else { $current_class = ''; $home_current_class = ''; }
        $menu_class = "page-item-" . $page->ID;
        echo "<li class='page_item ".esc_attr($menu_class)." $current_class'><a href='".esc_url($menu_link)."'>".esc_html($menu_name)."</a></li>";
        $i++;
    } 
    echo '</ul>';
	echo '</div>';
}

function juliet_example_footer_widgets(){
    
    echo '<div class="sidebar-footer footer-row-1">';
    echo '<div class="row">';
    
    echo '<div class="col-lg-3 col-md-3 col-sm-6 col-xs-12">';
    the_widget('WP_Widget_Pages', 'title=Pages', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="footer-row-1-widget widget">&after_widget=</div>');
    echo '</div>';
    
    echo '<div class="col-lg-3 col-md-3 col-sm-6 col-xs-12">';
    the_widget( 'WP_Widget_Archives', 'title=Archives', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="footer-row-1-widget widget">&after_widget=</div>');
    echo '</div>';
    
    echo '<div class="col-lg-3 col-md-3 col-sm-6 col-xs-12">';
    the_widget('WP_Widget_Recent_Posts', 'title=Recent Posts', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="footer-row-1-widget widget">&after_widget=</div>');
    echo '</div>';
    
    echo '<div class="col-lg-3 col-md-3 col-sm-6 col-xs-12">';
    the_widget( 'WP_Widget_Categories', 'title=Categories', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="footer-row-1-widget widget ">&after_widget=</div>');
    echo '</div>';
    
    echo '</div>';
    echo '</div>';
}

#juliet_example_sidebar
function juliet_example_sidebar(){
    echo '<div class="sidebar-default" >';
    the_widget('WP_Widget_Search', 'title=' . esc_html__('Search', 'juliet'), 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="default-widget widget widget_search">&after_widget=</div>');
    the_widget('WP_Widget_Pages', 'title=' . esc_html__('Pages', 'juliet') , 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="default-widget widget">&after_widget=</div>');
    the_widget('WP_Widget_Recent_Posts', 'title=' . esc_html__('Recent Posts', 'juliet') , 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="default-widget widget">&after_widget=</div>');
    the_widget( 'WP_Widget_Archives', 'title=' . esc_html__('Archives', 'juliet'), 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="default-widget widget">&after_widget=</div>');
    the_widget( 'WP_Widget_Categories', 'title=' . esc_html__('Categories', 'juliet'), 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="default-widget widget">&after_widget=</div>');
    echo '</div>';
}

/*------------------------------
 Helper
 ------------------------------*/
 
if ( ! function_exists( 'juliet_get_option' ) ) :
function juliet_get_option($key){
    global $juliet_defaults;
    if (array_key_exists($key, $juliet_defaults)) 
        $value = get_theme_mod($key, $juliet_defaults[$key]); 
    else
        $value = get_theme_mod($key);
    return $value;
}
endif;

if ( ! function_exists( 'juliet_get_bootstrap_class' ) ) :
function juliet_get_bootstrap_class($columns){
    switch($columns){
        case 1: return 'col-md-12'; break;
        case 2: return 'col-lg-6 col-md-6 col-sm-6'; break;
        case 3: return 'col-lg-4 col-md-4 col-sm-4 col-xs-12'; break;
        case 4: return 'col-lg-3 col-md-3 col-sm-6 col-xs-12'; break;
        case 5: return 'col-md-20'; break;
        case 6: return 'col-lg-2 col-md-2 col-sm-2 col-xs-6'; break;
    }
}
endif;

if ( ! function_exists( 'juliet_get_body_class' ) ) :
function juliet_get_body_class(){
    $class = 'boxed';
    if( (juliet_get_option('juliet_frontpage_banner') == 'Posts' || juliet_get_option('juliet_frontpage_banner') == 'Custom') && juliet_get_option('juliet_frontpage_slider_type') == 'Strip' ){
        $class = 'full';
    }
    return $class;
}
endif;

if ( ! function_exists( 'juliet_show_custom_css_field' ) ) :
function juliet_show_custom_css_field(){
    if(get_bloginfo('version') >= 4.7){
        $juliet_advanced_css = juliet_get_option('juliet_advanced_css');
        if($juliet_advanced_css == '') return false;
        else return true;
    } 
    return true;
}
endif;

#hex2rgb
function hex2rgb($hex) {
    #credits: http://bavotasan.com/2011/convert-hex-color-to-rgb-using-php/
    $hex = str_replace("#", "", $hex);

    if(strlen($hex) == 3) {
        $r = hexdec(substr($hex,0,1).substr($hex,0,1));
        $g = hexdec(substr($hex,1,1).substr($hex,1,1));
        $b = hexdec(substr($hex,2,1).substr($hex,2,1));
    } else {
        $r = hexdec(substr($hex,0,2));
        $g = hexdec(substr($hex,2,2));
        $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   //return $rgb; // returns an array with the rgb values
}

if ( ! function_exists( 'juliet_get_attachment' ) ) :
function juliet_get_attachment( $attachment_id ) {
	$attachment = get_post( $attachment_id );
	return array(
		'alt' => get_post_meta( $attachment->ID, '_wp_attachment_image_alt', true ),
		'caption' => $attachment->post_excerpt,
		'description' => $attachment->post_content,
		'href' => get_permalink( $attachment->ID ),
		'src' => $attachment->guid,
		'title' => $attachment->post_title
	);
}
endif;

function juliet_kirki_update_3015(){
    # version 3.0.15 is no longer using strings "0" or "1" for this control
    $switches = array(  'juliet_image_logo_show', 'juliet_frontpage_featured_posts_show', 'juliet_blog_feed_meta_show', 'juliet_posts_meta_show',
    'juliet_custom_colors', 'juliet_custom_typography', 'juliet_frontpage_featured_links_show', 'juliet_frontpage_large_post_show', 'juliet_frontpage_focus_show', 'juliet_enable_ads');
    foreach($switches as $switch) {
        $val = get_theme_mod( $switch, true ) ; 
        if($val == "0")    set_theme_mod( $switch, false ); 
    }
}
/*------------------------------
 Woocommerce
 ------------------------------*/

 require_once get_template_directory() . '/woocommerce/functions_woocommerce.php';
?>